==> dde-dock_5.4.10.orig.tar.xz: dde-dock-5.4.10/translations/dde-dock_gl_ES.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="gl_ES" version="2.1">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>O complemento %1 non é compatible co sistema.</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Axustes do Bluetooth</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Acender</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Axustes do Bluetooth</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 conectado</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Conectando...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Desactivado</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Engadir disposición do teclado</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Tempo da data</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>formato 12 horas</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>formato 24 horas</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Axustes da hora</translation>
    </message>
</context>
<context>
    <name>DeviceItem</name>
    <message>
        <source>Enable network</source>
        <translation>Activar a rede</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Desactivar a rede</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Axustes da rede</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Está certo/a de querer baleirar %1 elementos?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Esta acción non se pode desfacer</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Dispositivo descoñecido</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Volume descoñecido</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disco</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Desmontar todo</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Lanzador</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Modo moderno</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Modo eficiente</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Arriba</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Abaixo</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Dereita</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Manter visible</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Manter oculto</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Ocultar automaticamente</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Modo</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Localización</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>Complementos</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Vista multitarefa</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Desbordar</translation>
    </message>
</context>
<context>
    <name>NetworkItem</name>
    <message>
        <source>Disable wired connection</source>
        <translation>Desactivar a conexión con fíos</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Activa a conexión con fíos</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Desactivar a conexión sen fíos</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Activar a conexión sen fíos</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Desactivar a rede</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Activar a rede</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Axustes da rede</translation>
    </message>
    <message>
        <source>Device disabled</source>
        <translation>Dispositivo desactivado</translation>
    </message>
    <message>
        <source>Wireless connection: %1</source>
        <translation>Conexión sen fíos:% 1</translation>
    </message>
    <message>
        <source>Wired connection: %1</source>
        <translation>Conexión con fíos: %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Sen conexión</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Conectando</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Conectado pero sen acceso a internet</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Cabo de rede desconectado</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Rede sen fíos</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Rede con fíos</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Rede</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Rede con fíos</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Rede con fíos % 1</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>A bordo</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Axustes</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Enerxía</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Axustes de enerxía</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Capacidade %1,  %2 minutos restantes</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Capacidade %1,%2h %3m restantes</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Cargando %1, %2m até completar</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Cargando %1, %2h %3m até completar</translation>
    </message>
    <message>
        <source>Charged</source>
        <translation>Cargado</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Capacidade %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Cargando %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Capacidade %1...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Capacidade %1, totalmente cargada</translation>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Amosar escritorio</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Desbordar</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Enerxía</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernar</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Bloquear</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Pechar sesión</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Mudar de conta</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Axustes de enerxía</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>Dispositivo</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Desactivar silencio</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Silenciar</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Configuración do son</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Volume %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Son</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Lixo</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Lixo - %1 ficheiro</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Lixo - %1 ficheiros</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Baleirar</translation>
    </message>
</context>
<context>
    <name>TrayPlugin</name>
    <message>
        <source>System Tray</source>
        <translation>Bandexa do sistema</translation>
    </message>
</context>
<context>
    <name>WirelessList</name>
    <message>
        <source>Wireless Network</source>
        <translation>Rede sen fíos</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Rede sen fíos %1</translation>
    </message>
</context>
</TS>

==> dde-dock_5.5.38.1.orig.tar.xz: dde-dock-5.5.38.1/translations/dde-dock_gl_ES.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="gl_ES">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>O complemento %1 non é compatible co sistema.</translation>
    </message>
</context>
<context>
    <name>AirplaneModeApplet</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Acender</translation>
    </message>
    <message>
        <source>Airplane Mode settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Axustes do Bluetooth</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Acender</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Axustes do Bluetooth</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 conectado</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Conectando...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Desactivado</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Engadir disposición do teclado</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Tempo da data</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>formato 12 horas</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>formato 24 horas</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Axustes da hora</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Está certo/a de querer baleirar %1 elementos?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Esta acción non se pode desfacer</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Dispositivo descoñecido</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Volume descoñecido</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disco</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Desmontar todo</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Lanzador</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Modo moderno</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Modo eficiente</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Arriba</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Abaixo</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Dereita</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Manter visible</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Manter oculto</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Ocultar automaticamente</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Modo</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Localización</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <source>Dock settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ModuleWidget</name>
    <message>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
    <message>
        <source>Multiple Displays</source>
        <translation>Pantallas múltiple</translation>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fashion mode</source>
        <translation>Modo moderno</translation>
    </message>
    <message>
        <source>Efficient mode</source>
        <translation>Modo eficiente</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Modo</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Arriba</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Abaixo</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Dereita</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Localización</translation>
    </message>
    <message>
        <source>Keep shown</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Keep hidden</source>
        <translation>Manter oculto</translation>
    </message>
    <message>
        <source>Smart hide</source>
        <translation>Ocultar automaticamente</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Pequeno</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Grande</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Only on main screen</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Vista multitarefa</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Desbordar</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>A bordo</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Axustes</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Enerxía</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Axustes de enerxía</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Capacidade %1,  %2 minutos restantes</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Capacidade %1,%2h %3m restantes</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Cargando %1, %2m até completar</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Cargando %1, %2h %3m até completar</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Capacidade %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Cargando %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Capacidade %1...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Capacidade %1, totalmente cargada</translation>
    </message>
</context>
<context>
    <name>SettingsModule</name>
    <message>
        <source>Dock</source>
        <translation>Doca</translation>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Amosar escritorio</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Desbordar</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Enerxía</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernar</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Bloquear</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Pechar sesión</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Mudar de conta</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Axustes de enerxía</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>Dispositivo</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Desactivar silencio</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Silenciar</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Configuración do son</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Volume %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Son</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Lixo</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Lixo - %1 ficheiro</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Lixo - %1 ficheiros</translation>
    </message>
    <message>
        <source>Move to Trash</source>
        <translation>Mover ao lixo</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Baleirar</translation>
    </message>
</context>
</TS>
